==> manydhcp2.5.2.tar.bz2: manydhcp/service/importfrm_sams.php <==
<?php
  ///////////////////////////////////////////////////
  //2010 (C)
  //Карпухин Павел
  ///////////////////////////////////////////////////

  $lang = substr($_SERVER["HTTP_ACCEPT_LANGUAGE"], 0,2);
  if(is_file ("../lang/".$lang."/".$lang.".php")) include "../lang/".$lang."/".$lang.".php";
     else include "../lang/ru/ru.php";

  if(!isset($title)) $title = $TEXT['menu-btn37'];
  if(!isset($button)) $button = $TEXT['btn_run'];
  if(!isset($action)) $action = "import_sams.php";

  require_once "../config_a.php";
  require_once "../utils/functions.php";
  require_once "../utils/top_adm.php";

  if($result2['administrator'] == 0) {puterror($result2['skin'],$TEXT['error-loginform2']); require_once "../utils/bottom_adm.php"; exit();}

?>
<form enctype='multipart/form-data' action=<?php echo $action; ?> method=post>
<table align="center" >
<tr><td class="bold_it_page"><?php echo $TEXT['grp-kuda']; ?>:</td>
    <td><select name="srv_id">
    <?php
        $query1 = "SELECT srv_id, name, descr FROM `tbl_srv` ORDER BY name";
        $srv_tmp = mysql_query($query1);
          if(!$srv_tmp) puterror2($TEXT['error-tbl1']);
              while($srv = mysql_fetch_array($srv_tmp))
                {
                $chk = "<option value=".$srv['srv_id'].">".$srv['name']."(".$srv['descr'].")";
                echo $chk;
                }
    ?>
    </select></td></tr>
<tr><td class="bold_it_page"><?php echo $TEXT['global-import-file']; ?></td><td><input type=file name=impfl ></td></tr>
<tr><td class="bold_it_page"><?php echo $TEXT['grp-prefixiskh']; ?>*</td><td class="bold_it"><input size=20 maxlength=255 class="input" type=text name=prefix /></td></tr>
<tr><td class="bold_it_page"><?php echo $TEXT['grp-prefixnaz']; ?>*</td><td class="bold_it"><input size=20 maxlength=255 class="input" type=text name=prefixnaz /></td></tr>
<tr><td class="bold_it_page"><?php echo $TEXT['grp-obr-disabled']; ?></td><td class="del_frm_chkb"><input type=checkbox name=vikl_ip ></td></tr>
<tr><td class="bold_it_page"><?php echo $TEXT['addr-to-sams']; ?>:</td><td><input type=checkbox name=sams_ch ></td></tr>
<tr><td class="bold_it_page"><?php echo $TEXT['grp-razd']; ?>:</td><td>
 <input type=radio name=typefile value=1 checked >&#059;<br />
 <input type=radio name=typefile value=2>&#044;
<tr><td></td><td><input class="button2" type=submit value='<?php echo $button; ?>'></td></tr>
</table>
</form>
<?php
  require_once "../utils/bottom_adm.php";
?>

==> manydhcp2.8.2.tar.bz2: manydhcp/service/importfrm_sams.php <==
<?php
  ///////////////////////////////////////////////////
  //2010 (C)
  //Карпухин Павел
  ///////////////////////////////////////////////////

  $lang = substr($_SERVER["HTTP_ACCEPT_LANGUAGE"], 0,2);
  if(is_file ("../lang/".$lang."/".$lang.".php")) {include "../lang/".$lang."/".$lang.".php";}
     else {include "../lang/ru/ru.php";}

  $title = $TEXT['menu-btn37'];
  $button = $TEXT['btn_run'];
  $action = "import_sams.php";

  require_once "../config_a.php";
  require_once "../utils/functions.php";
  require_once "../utils/top_adm.php";

  if($result2['administrator'] == 0) {puterror($result2['skin'],$TEXT['error-loginform2']); require_once "../utils/bottom_adm.php"; exit();}

?>
<form enctype='multipart/form-data' action=<?php echo $action; ?> method=post>
<table align="center" >
<tr><td class="bold_it_page"><?php echo $TEXT['grp-kuda']; ?>:</td>
    <td><select name="srv_id">
    <?php
        $query1 = "SELECT srv_id, name, descr FROM `tbl_srv` ORDER BY name";
        $srv_tmp = mysqli_query($dbcnx,$query1);
          if(!$srv_tmp) {puterror2($TEXT['error-tbl1']);}
              while($srv = mysqli_fetch_array($srv_tmp,MYSQLI_ASSOC))
                {
                $chk = "<option value=".$srv['srv_id'].">".$srv['name']."(".$srv['descr'].")";
                echo $chk;
                }
    ?>
    </select></td></tr>
<tr><td class="bold_it_page"><?php echo $TEXT['global-import-file']; ?></td><td><input type=file name=impfl ></td></tr>
<tr><td class="bold_it_page"><?php echo $TEXT['grp-prefixiskh']; ?>*</td><td class="bold_it"><input size=20 maxlength=255 class="input" type=text name=prefix /></td></tr>
<tr><td class="bold_it_page"><?php echo $TEXT['grp-prefixnaz']; ?>*</td><td class="bold_it"><input size=20 maxlength=255 class="input" type=text name=prefixnaz /></td></tr>
<tr><td class="bold_it_page"><?php echo $TEXT['grp-obr-disabled']; ?></td><td class="del_frm_chkb"><input type=checkbox name=vikl_ip ></td></tr>
<tr><td class="bold_it_page"><?php echo $TEXT['addr-to-sams']; ?>:</td><td><input type=checkbox name=sams_ch ></td></tr>
<tr><td class="bold_it_page"><?php echo $TEXT['grp-razd']; ?>:</td><td>
 <input type=radio name=typefile value=1 checked >&#059;<br />
 <input type=radio name=typefile value=2>&#044;
<tr><td></td><td><input class="button2" type=submit value='<?php echo $button; ?>'></td></tr>
</table>
</form>
<?php
  require_once "../utils/bottom_adm.php";
?>
